#!/bin/tcsh -f

#update input and output directories here
# where are these scripts
set script_dir = .
# location of input coordinates and connection information
set coord_dir = .
# output for SUMA connection niml dataset with surface volumes
set SUMA_data_dir = /Users/dglen/atlas/macaque/macaqueatlas
# data volumes and macaque atlas datasets for talking to SUMA
#  same location in this example
set AFNI_data_dir = /Users/dglen/atlas/macaque/macaqueatlas

setenv AFNI_1D_ZERO_TEXT YES

tcsh ${coord_dir}/@coords_to_RAI -or PIL roi_names_coordinates.txt

# shift input coordinates by some amount computed from picking
#    approximate point on surface
# "good" for f99 tcsh ./@shift_coords 1 23 -14 RAIcoords.1D > RAIcoords_adjusted.1D
# 0 20 -12 estimated for D99 data, but Saleem has 0 -20 -14
#  not sure why sign is different for R-C -> A-P, but need to verify visually
#  and change coordinate D-V -> I-S shift to -14
# -12 sphere above brain, -14 sphere below brain, try -13 instead
tcsh ${script_dir}/@shift_coords 0 20 -13 RAIcoords.1D > RAIcoords_adjusted.1D

# create edge lists
echo "# list of edges - ROI1# ROI2#" > EdgeList.1D
foreach roiconn_file ( *_connections.txt )
   set roiname  = `basename -s _connections.txt $roiconn_file`
   set roiindex = `grep $roiname roi_names_coordinates.txt | awk '{print $1}'` 
   tcsh ${script_dir}/@create_edge_list $roiconn_file $roiindex >> EdgeList.1D
end

# combine the connections into a single file 
cat *_connections.txt  > combined_matrix.1D
 
# get roi# and name column only (ignore coordinates in this output)
cat ${coord_dir}/roi_names_coordinates.txt | \
   awk '{printf("%s %s\n",$1,$2)}' > ROI_i_names.txt

# convert the connection-coordinate info to a niml graph dataset
# combined_matrix.1D[1] is the connection strength column
# ROI_i_names.txt is roi# name
# Edgelist.1D is edge roi1 roi2, corresponding to connection strength
#   from combined_matrix.1D[1]
# RAIcoords_adjusted.1D[1,2,3] - RAI coordinates of rois in ROI_i_names.txt 
ConvertDset -i combined_matrix.1D'[1]'  \
            -o_niml_asc  -prefix  all_mat2_D99 \
            -add_node_index \
            -graph_named_nodelist_txt ${coord_dir}/ROI_i_names.txt \
                      RAIcoords_adjusted.1D'[1,2,3]' \
            -overwrite \
            -graphize    \
            -graph_edgelist_1D EdgeList.1D

# copy niml graph dataset to the SUMA directory
cp all_mat2_D99.niml.dset ${SUMA_data_dir}/

echo "To see results with these connections, type:"
echo "   cd $SUMA_data_dir"
echo "    afni -yesplugouts -niml -dset ${AFNI_data_dir}/D99s_template+tlrc"

echo  "  suma -onestate -i D99_L_AVG_T1_v2.L.MID.167625.surf.gii \\
     -i D99_L_AVG_T1_v2.R.MID.167625.surf.gii \\
     -sv ${AFNI_data_dir}/D99s_template+tlrc \\
     -vol ${AFNI_data_dir}/D99s_template+tlrc \\
     -gdset all_mat2_D99.niml.dset &"



